==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/misc/BaguaFurnaceEntity.java <==
package cc.thonly.reverie_dreams.entity.misc;

import cc.thonly.reverie_dreams.danmaku.DanmakuTrajectory;
import cc.thonly.reverie_dreams.danmaku.DanmakuTypes;
import cc.thonly.reverie_dreams.entity.ModEntities;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import org.jetbrains.annotations.NotNull;

public class BaguaFurnaceEntity extends class_1297 implements BypassHitEntity{
    private static final int MAX_TICK = 300;
    private static final int PER_INTERVAL_TICK1 = 1;
    private static final int PER_INTERVAL_TICK2 = 5 * 20;
    private final class_1309 owner;
    private int livingTick = 0;
    private int intervalTick1 = 0;
    private int intervalTick2 = 0;

    private final float fixedPitch;
    private final float fixedYaw;


    public BaguaFurnaceEntity(class_1299<? extends class_1297> entityType, class_1937 world) {
        super(entityType, world);
        this.owner = null;
        this.fixedPitch = 0;
        this.fixedYaw = 0;
    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {

    }

    public BaguaFurnaceEntity(class_3218 world, @NotNull class_1309 owner) {
        super(ModEntities.BAGUA_FURNACE_ENTITY, world);
        this.owner = owner;

        this.method_36457(owner.method_36455());
        this.method_36456(owner.method_36454());
        class_243 v3d = owner.method_19538();
        this.method_33574(v3d);
        this.method_5814(v3d.field_1352, owner.method_23320(), v3d.field_1350);

        double offsetX = -Math.sin(Math.toRadians(this.method_36454()));
        double offsetZ = Math.cos(Math.toRadians(this.method_36454()));
        this.method_23327(this.method_23317() + offsetX, this.method_23318(), this.method_23321() + offsetZ);

        this.fixedPitch = owner.method_36455();
        this.fixedYaw = owner.method_36454();
    }

    @Override
    public void method_5773() {
        super.method_5773();
        if (this.livingTick > MAX_TICK) {
            this.method_31472();
            return;
        }
        if (this.owner == null) return;

        if (this.intervalTick1 <= 0) {
            DanmakuEntity entity = DanmakuTrajectory.spawnByItemStack(
                    (class_3218) this.method_37908(),
                    null,
                    this.method_23317(), this.method_23318(), this.method_23321(),
                    DanmakuTypes.random(DanmakuTypes.BIG_LASER),
                    fixedPitch, fixedYaw,
                    1.6f, 0f, 0.0f, 0.5f
            );
            entity.method_7432(this.owner);
            this.intervalTick1 = PER_INTERVAL_TICK1;
        }

        if (this.intervalTick2 <= 0) {
            this.method_37908().method_45447(
                    null, this.owner.method_24515(),
                    SoundEventInit.BAGUA, class_3419.field_15248
            );
            this.intervalTick2 = PER_INTERVAL_TICK2;
        }

        this.livingTick++;
        this.intervalTick1--;
        this.intervalTick2--;
    }

    @Override
    public boolean method_64397(class_3218 world, class_1282 source, float amount) {
        return false;
    }

    @Override
    protected void method_5749(class_11368 view) {
        this.livingTick = view.method_71424("LivingTick", MAX_TICK);
        this.intervalTick1 = view.method_71424("IntervalTick1", PER_INTERVAL_TICK1);
        this.intervalTick1 = view.method_71424("IntervalTick2", PER_INTERVAL_TICK2);
    }

    @Override
    protected void method_5652(class_11372 view) {
        view.method_71465("LivingTick", this.livingTick);
        view.method_71465("IntervalTick1", this.intervalTick1);
        view.method_71465("IntervalTick2", this.intervalTick2);
    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/misc/BaguaFurnaceEntity.java <==
package cc.thonly.reverie_dreams.entity.misc;

import cc.thonly.reverie_dreams.data.danmaku.DanmakuTrajectory;
import cc.thonly.reverie_dreams.registry.content.danmaku.DanmakuTypes;
import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import org.jetbrains.annotations.NotNull;

public class BaguaFurnaceEntity extends class_1297 implements BypassHitEntity {
    private static final int MAX_TICK = 300;
    private static final int PER_INTERVAL_TICK1 = 1;
    private static final int PER_INTERVAL_TICK2 = 5 * 20;
    private final class_1309 owner;
    private int livingTick = 0;
    private int intervalTick1 = 0;
    private int intervalTick2 = 0;

    private final float fixedPitch;
    private final float fixedYaw;


    public BaguaFurnaceEntity(class_1299<? extends class_1297> entityType, class_1937 world) {
        super(entityType, world);
        this.owner = null;
        this.fixedPitch = 0;
        this.fixedYaw = 0;
    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {

    }

    public BaguaFurnaceEntity(class_3218 world, @NotNull class_1309 owner) {
        super(RDEntityTypes.BAGUA_FURNACE_ENTITY, world);
        this.owner = owner;

        this.method_36457(owner.method_36455());
        this.method_36456(owner.method_36454());
        class_243 v3d = owner.method_19538();
        this.method_33574(v3d);
        this.method_5814(v3d.field_1352, owner.method_23320(), v3d.field_1350);

        double offsetX = -Math.sin(Math.toRadians(this.method_36454()));
        double offsetZ = Math.cos(Math.toRadians(this.method_36454()));
        this.method_23327(this.method_23317() + offsetX, this.method_23318(), this.method_23321() + offsetZ);

        this.fixedPitch = owner.method_36455();
        this.fixedYaw = owner.method_36454();
    }

    @Override
    public void method_5773() {
        super.method_5773();
        if (this.livingTick > MAX_TICK) {
            this.method_31472();
            return;
        }
        if (this.owner == null) return;

        if (this.intervalTick1 <= 0) {
            DanmakuEntity entity = DanmakuTrajectory.spawnByItemStack(
                    (class_3218) this.method_37908(),
                    null,
                    this.method_23317(), this.method_23318(), this.method_23321(),
                    DanmakuTypes.random(DanmakuTypes.BIG_LASER),
                    fixedPitch, fixedYaw,
                    0.0f, 0.5f
            );
            entity.method_7432(this.owner);
            this.intervalTick1 = PER_INTERVAL_TICK1;
        }

        if (this.intervalTick2 <= 0) {
            this.method_37908().method_45447(
                    null, this.owner.method_24515(),
                    SoundEventInit.BAGUA, class_3419.field_15248
            );
            this.intervalTick2 = PER_INTERVAL_TICK2;
        }

        this.livingTick++;
        this.intervalTick1--;
        this.intervalTick2--;
    }

    @Override
    public boolean method_64397(class_3218 world, class_1282 source, float amount) {
        return false;
    }

    @Override
    protected void method_5749(class_11368 view) {
        this.livingTick = view.method_71424("LivingTick", MAX_TICK);
        this.intervalTick1 = view.method_71424("IntervalTick1", PER_INTERVAL_TICK1);
        this.intervalTick1 = view.method_71424("IntervalTick2", PER_INTERVAL_TICK2);
    }

    @Override
    protected void method_5652(class_11372 view) {
        view.method_71465("LivingTick", this.livingTick);
        view.method_71465("IntervalTick1", this.intervalTick1);
        view.method_71465("IntervalTick2", this.intervalTick2);
    }

}
